@@ -40,12 +40,15 @@ ktri = 0
 1       continue
 
 # Check that the vertices of the triangle listed in tau are
-# in anticlockwise order.  (If they aren't then alles upgefucken
-# ist; throw an error.)
+# in anticlockwise order.  (If they aren't then reverse the order;
+# if they are *still*  not in anticlockwise order, theh alles
+# upgefucken ist; throw an error.)
 call acchk(tau(1),tau(2),tau(3),anticl,x,y,ntot,eps)
 if(!anticl) {
     call acchk(tau(3),tau(2),tau(1),anticl,x,y,ntot,eps)
     if(!anticl) {
+        call intpr("Point number =",-1,j,1)
+        call intpr("Previous triangle:",-1,tau,3)
         call rexit("Both vertex orderings are clockwise. See help for deldir.")
     } else {
         ivtmp  = tau(3)
