@@ -2,6 +2,7 @@ C Output from Public domain Ratfor, version 1.03
       subroutine circen(i,j,k,x0,y0,x,y,ntot,eps,collin,nerror)
       implicit double precision(a-h,o-z)
       dimension x(-3:ntot), y(-3:ntot), xt(3), yt(3)
+      dimension indv(3)
       logical collin
       nerror = -1
       xt(1) = x(i)
@@ -30,8 +31,12 @@ C Output from Public domain Ratfor, version 1.03
       if(collin)then
       alpha = a*c+b*d
       if(alpha.gt.0)then
-      nerror = 3
-      return
+      indv(1) = i
+      indv(2) = j
+      indv(3) = k
+      call intpr("Point numbers:",-1,indv,3)
+      call dblepr("Test value:",-1,alpha,1)
+      call rexit("Points are collinear but in the wrong order.")
       endif
       return
       endif
